==> haskell-either-5.0.3-73.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 either
version:              5.0.3
visibility:           public
id:                   either-5.0.3-LXBywpYsrH13GkjtmaGjK1
key:                  either-5.0.3-LXBywpYsrH13GkjtmaGjK1
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/either/
synopsis:             Combinators for working with sums
description:          Combinators for working with sums.
category:             Control, Monads
abi:                  f9073c63f5c7329347928102ad797f78
exposed:              True
exposed-modules:      Data.Either.Combinators Data.Either.Validation
import-dirs:          /usr/lib/ghc-9.6.6/site-local/either-5.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/either-5.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/either-5.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-either
hs-libraries:         HSeither-5.0.3-LXBywpYsrH13GkjtmaGjK1
depends:
    base-4.18.2.1 bifunctors-5.6.2-46LlpbtsnGiKfj3D3n0SSf mtl-2.3.1
    profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9

haddock-interfaces:   /usr/share/doc/haskell-either/html/either.haddock
haddock-html:         /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-5.0.3-74-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 either
version:              5.0.3
visibility:           public
id:                   either-5.0.3-AwsJObJJa5t15rwL7Wjn2s
key:                  either-5.0.3-AwsJObJJa5t15rwL7Wjn2s
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/either/
synopsis:             Combinators for working with sums
description:          Combinators for working with sums.
category:             Control, Monads
abi:                  08e5d4d08e30d714c259791c1faade6f
exposed:              True
exposed-modules:      Data.Either.Combinators Data.Either.Validation
import-dirs:          /usr/lib/ghc-9.6.6/site-local/either-5.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/either-5.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/either-5.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-either
hs-libraries:         HSeither-5.0.3-AwsJObJJa5t15rwL7Wjn2s
depends:
    base-4.18.2.1 bifunctors-5.6.2-A3wf66Vnx89CEVmymYgSB mtl-2.3.1
    profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS

haddock-interfaces:   /usr/share/doc/haskell-either/html/either.haddock
haddock-html:         /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
